function [indicators] = LR(source, target,loc)

sourcedata =source(:,1:end-1);
sourcelabel = source(:,end);
targetdata = target(:,1:end-1);
targetlabel = target(:,end);

model = train(sourcelabel, sparse(real(sourcedata)),'-s 0 -c 1 -B -1 -q'); % num * fec
[predictlabel,~, prob_estimates] = predict(targetlabel, sparse(real(targetdata)), model,'-b 1');

if (predictlabel(1) == 0) && (prob_estimates(1,1)< prob_estimates(1,2))
    score = prob_estimates(:,1);
elseif (predictlabel(1) == 0) && (prob_estimates(1,1)> prob_estimates(1,2))
    score = prob_estimates(:,2);
elseif (predictlabel(1) == 1) && (prob_estimates(1,1)< prob_estimates(1,2))
    score = prob_estimates(:,2);
elseif (predictlabel(1) == 1) && (prob_estimates(1,1)> prob_estimates(1,2))
    score = prob_estimates(:,1);
end
logitFit = score;

predictlabel_zhuanzhi = predictlabel';
targetlabel_zhuanzhi = targetlabel';

TN = 0;
FP = 0;
FN = 0;
TP = 0;
for i = 1:size(targetlabel_zhuanzhi,2)
    if (targetlabel_zhuanzhi(i)== 0 && predictlabel_zhuanzhi(i) == 0)
	    TN = TN + 1;
	elseif (targetlabel_zhuanzhi(i) == 0 && predictlabel_zhuanzhi(i) == 1)
        FP = FP + 1;
	elseif (targetlabel_zhuanzhi(i) == 1 && predictlabel_zhuanzhi(i) == 0)
        FN = FN + 1;
    else
        TP = TP + 1;
    end
end

% the traditional indicators
Recall = TP / (TP + FN);
Pd = Recall;
Precision = TP / (TP + FP);
False_Positive = FP / (FP + TN);
Pf = False_Positive;
F_measure = 2 * Precision * Recall / (Precision + Recall);
g_mean = sqrt((TN / (TN + FP)) * (TP / (TP + FN)));
Bal = 1- sqrt((0-Pf)^2+(1-Pd)^2)/sqrt(2);

traditional_indicators = [F_measure,g_mean, Bal];

%calculate the effort-aware indicators
index_defect = find(score > 0.5); % the indexs of the predicted defective modules
index_non_defect = find(score <= 0.5);
predicted_defect_actuallabel = targetlabel(index_defect); %the actual labels of these predicted defective modules
predicted_non_defect_actuallabel = targetlabel(index_non_defect);% the actual labels of these predicted non-defective modules
predicted_defect_LOC = loc(index_defect); % the LOC values of these predicted defective modules
predicted_non_defect_LOC = loc(index_non_defect);% the LOC values of these predicted non-defective modules

[LOC_defect_SORT, index_defect_LOC] = sort(predicted_defect_LOC); % sort the predicted defective modules based on LOC 
[LOC_non_defect_SORT, index_non_defect_LOC] = sort(predicted_non_defect_LOC); % sort the predicted non-defective modules based on LOC 
LOC_SORT = [LOC_defect_SORT;LOC_non_defect_SORT]; % combine the two sorting results

predicted_defect_actuallabel_sort = predicted_defect_actuallabel(index_defect_LOC); % sort the actual labels of the predicted defective modules based on LOC
predicted_non_defect_actuallabel_sort = predicted_non_defect_actuallabel(index_non_defect_LOC);% sort the actual labels of the predicted non-defective modules based on LOC
predicted_actuallabel_sort = [predicted_defect_actuallabel_sort;predicted_non_defect_actuallabel_sort]; % combine

CumLOC = 100 * cumsum(LOC_SORT)./sum(loc);
Cutoffindex = find(CumLOC >= 20);
Cutoffindex(1);

predicted_actuallabel_cutoff20 = predicted_actuallabel_sort(1:Cutoffindex(1));

% Suppose having a dataset with M modules and N defects.
% After inspecting 20% LOC, we inspected m modules and found n defects. 
% Besides, when we find the first defective module, we have inspected k modules.

M = size(targetlabel,1);
N = sum(targetlabel);
m = Cutoffindex(1);
n = sum(predicted_actuallabel_cutoff20);

Effort_Recall = n/N;
Effort_Precision = n/m;
Effort_F = 2 * Effort_Precision * Effort_Recall / (Effort_Precision + Effort_Recall);
effort_aware_indicators = [Effort_Recall, Effort_F];

indicators =[traditional_indicators,effort_aware_indicators]